summaryrefslogtreecommitdiffstats
path: root/src/panfrost
diff options
context:
space:
mode:
authorAlyssa Rosenzweig <[email protected]>2019-12-05 09:06:53 -0500
committerAlyssa Rosenzweig <[email protected]>2019-12-06 14:37:17 +0000
commitadf716dc7f17afd841feb86de45dd6bf91678333 (patch)
treeb9dd91041c75eb5897fcace7d322f52886731865 /src/panfrost
parent9eae950342fe96c717c740f0827a572cd41d85fc (diff)
panfrost: Rename SET_VALUE to WRITE_VALUE
See https://lists.freedesktop.org/archives/dri-devel/2019-December/247601.html Write value emphasises that it's just a generic write primitive. Signed-off-by: Alyssa Rosenzweig <[email protected]>
Diffstat (limited to 'src/panfrost')
-rw-r--r--src/panfrost/include/panfrost-job.h8
-rw-r--r--src/panfrost/pandecode/decode.c10
2 files changed, 9 insertions, 9 deletions
diff --git a/src/panfrost/pandecode/decode.c b/src/panfrost/pandecode/decode.c
index 79b3dd9088e..d112f104b43 100644
--- a/src/panfrost/pandecode/decode.c
+++ b/src/panfrost/pandecode/decode.c
@@ -309,7 +309,7 @@ pandecode_job_type(enum mali_job_type type)
switch (type) {
DEFINE_CASE(NULL);
- DEFINE_CASE(SET_VALUE);
+ DEFINE_CASE(WRITE_VALUE);
DEFINE_CASE(CACHE_FLUSH);
DEFINE_CASE(COMPUTE);
DEFINE_CASE(VERTEX);
@@ -2901,13 +2901,13 @@ pandecode_jc(mali_ptr jc_gpu_va, bool bifrost, unsigned gpu_id)
* reason. */
switch (h->job_type) {
- case JOB_TYPE_SET_VALUE: {
- struct mali_payload_set_value *s = payload;
- pandecode_log("struct mali_payload_set_value payload_%"PRIx64"_%d = {\n", payload_ptr, job_no);
+ case JOB_TYPE_WRITE_VALUE: {
+ struct mali_payload_write_value *s = payload;
+ pandecode_log("struct mali_payload_write_value payload_%"PRIx64"_%d = {\n", payload_ptr, job_no);
pandecode_indent++;
MEMORY_PROP(s, address);
- if (s->value_descriptor != MALI_SET_VALUE_ZERO) {
+ if (s->value_descriptor != MALI_WRITE_VALUE_ZERO) {
pandecode_msg("XXX: unknown value descriptor\n");
pandecode_prop("value_descriptor = 0x%" PRIX32, s->value_descriptor);
}
diff --git a/src/panfrost/include/panfrost-job.h b/src/panfrost/include/panfrost-job.h
index bb033e3566a..53e4f59f121 100644
--- a/src/panfrost/include/panfrost-job.h
+++ b/src/panfrost/include/panfrost-job.h
@@ -34,7 +34,7 @@
enum mali_job_type {
JOB_NOT_STARTED = 0,
JOB_TYPE_NULL = 1,
- JOB_TYPE_SET_VALUE = 2,
+ JOB_TYPE_WRITE_VALUE = 2,
JOB_TYPE_CACHE_FLUSH = 3,
JOB_TYPE_COMPUTE = 4,
JOB_TYPE_VERTEX = 5,
@@ -657,12 +657,12 @@ enum mali_exception_access {
MALI_EXCEPTION_ACCESS_WRITE = 3
};
/* Details about set_value from panfrost igt tests which use it as a generic
* dword write primitive */
-#define MALI_SET_VALUE_ZERO 3
+#define MALI_WRITE_VALUE_ZERO 3
-struct mali_payload_set_value {
+struct mali_payload_write_value {
u64 address;
u32 value_descriptor;
u32 reserved;
@@ -657,12 +657,12 @@ enum mali_exception_access {
MALI_EXCEPTION_ACCESS_WRITE = 3
};
-/* Details about set_value from panfrost igt tests which use it as a generic
+/* Details about write_value from panfrost igt tests which use it as a generic
* dword write primitive */